OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, seleccione un archivo.",
    "File is too big" : "El archivo es demasiado grande",
    "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
    "The selected file cannot be read." : "El archivo seleccionado no puede ser leído.",
    "The file was uploaded" : "El archivo fue subido",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo subido excede la directiva upload_max_filesize del php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido excede la directiva MAX_FILE_SIZE que fue especificada en el formulario HTML",
    "The file was only partially uploaded" : "El archivo fue subido parcialmente",
    "No file was uploaded" : "El archivo no fue subido",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se pudo escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión PHP detuvola subida del archivo",
    "Invalid file provided" : "Archivo no válido",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Ha ocurrido un error. Póngase en contacto con su administrador.",
    "Invalid image" : "La imagen no es válida",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se han proporcionado datos del recorte",
    "No valid crop data provided" : "Recorte inválido",
    "Crop is not square" : "El recorte no es cuadrado",
    "State token does not match" : "El token dado no coincide",
    "Invalid app password" : "Contraseña de la app no válida",
    "Could not complete login" : "No se ha podido completar el inicio de sesión",
    "Your login token is invalid or has expired" : "Tu token de login no es válido o ha caducado",
    "Login" : "Iniciar sesión",
    "Password reset is disabled" : "El restablecimiento de la contraseña está deshabilitado",
    "Could not reset password because the token is expired" : "No se puede restablecer la contraseña porque el token de autenticación ha caducado.",
    "Could not reset password because the token is invalid" : "No se puede restablecer la contraseña porque el token de autenticación no es válido.",
    "%s password reset" : "%s restablecer contraseña",
    "Password reset" : "Restablecer contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haz clic en el siguiente botón para restaurar tu contraseña. Si no has solicitado que se te restaure la contraseña, ignora este correo.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haz clic en el siguiente enlace para restaurar tu contraseña. Si no has solicitado que se te restaure la contraseña, ignora este correo.",
    "Reset your password" : "Resetear su contraseña",
    "Nextcloud Server" : "Servidor Nexcloud",
    "Some of your link shares have been removed" : "Algunos de tus enlaces compartidos han sido eliminados.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un bug de seguridad hemos tenido que eliminar algunos de tus enlaces compartidos. Por favor, accede al link para más información.",
    "The user limit of this instance is reached." : "Se alcanzó el límite de usuarios de esta instancia.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduzca su clave de suscripción para aumentar el límite de usuarios. Para obtener más información sobre Nextcloud Enterprise, visite nuestro sitio web.",
    "Preparing update" : "Preparando la actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Paso de reparación:",
    "Repair info:" : "Información de reparación:",
    "Repair warning:" : "Advertencia de reparación:",
    "Repair error:" : "Error que reparar:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor utilice la actualización mediante la linea de comandos porque la actualización automática está desactivada en config.php.",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo mantenimiento aún está activo.",
    "Updating database schema" : "Actualizando el esquema del base de datos",
    "Updated database" : "Base de datos actualizada",
    "Update app \"%s\" from App Store" : "Actualizar la app \"%s\" desde la App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos %s (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" actualizado a %2$s",
    "Set log level to debug" : "Establecer el nivel de registro a depuración",
    "Reset log level" : "Restablecer el nivel de registro",
    "Starting code integrity check" : "Comenzando comprobación de integridad de código",
    "Finished code integrity check" : "Terminada la comprobación de integridad de código",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Las siguientes apps han sido desactivadas: %s",
    "Already up to date" : "Ya actualizado",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web todavía no está configurado correctamente para permitir la sincronización de archivos, porque la interfaz WebDAV parece estar rota.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Su servidor no está configurado correctamente para resolver \"{url}\". Se puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Tu servidor no está bien configurado para resolver \"{url}\". Esto podría estar relacionado con que la configuración del servidor web que no se ha actualizado para entregar esta carpeta directamente. Por favor, compara tu configuración con las reglas de reescritura del \".htaccess\" para Apache o la provista para Nginx en la {linkstart}página de documentación ↗{linkend}. En Nginx, suelen ser las líneas que empiezan con \"location ~\" las que hay que actualizar.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Tu servidor web no está bien configurado para suministrar archivos .woff2 . Esto suele ser un problema de la configuración de Nginx. Para Nextcloud 15, necesita un ajuste para suministrar archivos .woff2. Compare su configuración de Nginx con la configuración recomendada en nuestra {linkstart}documentación ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP parece no estar correctamente configurado para solicitar las variables de entorno de sistema. La prueba con getenv(\"PATH\") solo devuelve una respuesta vacía.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, compruebe las notas de configuración de PHP en la {linkstart}documentación de instalación ↗{linkend} y la configuración de PHP de su servidor, especialmente cuando se utiliza php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Se ha activado la configuración de solo lectura. Esto evita cambiar ciertas configuraciones vía la interfaz web. Además, el archivo debe hacerse escribible de manera manual para cada actualización.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "No has configurado o verificado todavía los datos de servidor de correo. Por favor, dirígete a la {mailSettingsStart}Configuración básica{mailSettingsEnd} para hacerlo. A continuación, usa el botón de \"Enviar correo\" bajo el formulario para verificar tu configuración.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no funciona con el nivel de aislamiento de transacciones \"READ COMMITTED\". Esto puede causar problemas cuando se ejecutan en paralelo varias acciones.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Falta el módulo PHP \"fileinfo\". Se recomienda fervientemente activar este módulo para conseguir los mejores resultados con la detección de tipos MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "El bloqueo transaccional de archivos está desactivado, lo que podría ocasionar problemas en casos de acceso simultáneo. Habilite \"filelocking.enabled\" en el config.php para evitar estos problemas. Compruebe la {linkstart}documentación ↗{linkend} para más información.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Por favor, asegúrate de establecer la URL con la que tus usuarios acceden normalmente a este Nextcloud en la opción \"overwrite.cli.url\" del archivo config.php. Sugerencia: \"{suggestedOverwriteCliURL}\". De lo contrario, podría haber problemas con las URL generadas a través de cron. (Es posible que la URL sugerida no sea la que sus usuarios utilizan normalmente para acceder a este Nextcloud. En cualquier caso, lo mejor es comprobarlo).",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "La instalación no tiene establecida una región telefónica predeterminada. Esto es necesario para validar los números de teléfono en la configuración del perfil sin un código de país. Para permitir números sin código de país, por favor agregue \"default_phone_region\" con el respectivo {linkstart}código ISO 3166-1 ↗{linkend} de la región a su archivo de configuración.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No se ha podido ejecutar el trabajo cron vía CLI. Han aparecido los siguientes errores técnicos:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "La última ejecución de los trabajos en segundo plano fue hace {relativeTime}. Parece que algo va mal. {linkstart}Compruebe la configuración de los trabajos en segundo plano ↗{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor no tiene una conexión a Internet que funcione: No se pudieron alcanzar varios puntos finales. Esto significa que algunas de las funciones, como montar almacenamiento externo, notificaciones sobre actualizaciones o instalación de aplicaciones de terceros no funcionarán. Es posible que el acceso a archivos de forma remota y el envío de emails de notificación tampoco funcionen. Establezca una conexión desde este servidor a Internet para disfrutar de todas las funciones.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La memoria caché no ha sido configurada. Para mejorar el rendimiento, por favor, configure memcache si está disponible. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No se ha encontrado una fuente de aleatoriedad en PHP, lo que se desaconseja por razones de seguridad. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Actualmente está ejecutando PHP {version}. Actualize la versión de PHP para beneficiarse de las  {linkstart}actualizaciones de rendimiento y seguridad que aporta PHP Group ↗{linkend} en cuanto su distribución lo soporte.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 es la última versión compatible con PHP 7.3. Nextcloud 24 requiere al menos PHP 7.4.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La configuración de la cabecera del proxy reverso no es correcta o está accediendo a Nextcloud desde un proxy de confianza. Si no, esto es un problema de seguridad y podría permitir a un ataccante a disfrazar su dirección IP como visible para Nextcloud. Se puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached está configurado como una caché distribuida, pero se ha instalado el módulo equivocado de PHP \"memcache\". \\OC\\Memcache\\Memcached solo soporta \"memcached\" y no \"memcache\". Comprueba la {linkstart}wiki de memcached wiki acerca de ambos módulos ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Algunos archivos no han pasado la comprobación de integridad. Puede encontrar más información sobre cómo resolver este problema en la {linkstart1}documentacióarchivosn ↗{linkend}. ({linkstart2}Lista de archivos no válidos…{linkend} / {linkstart3}Rescanear…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "El módulo PHP OPcache no está configurado adecuadamente. Echa un vistazo a la {linkstart}documentación↗{linkend} para más información.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función PHP \"set_time_limit\" no está disponible. Esto podría resultar en scripts detenidos a mitad de ejecución, rompiendo tu instalación. Activar esta función está fuertemente recomendado.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no tiene soporte FreeType, lo que provoca una rotura en las imágenes de perfil y en la interfaz de los ajustes.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Índice perdido \"{indexName}\" en la tabla \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos le faltan algunos índices. Debido al hecho de que añadir índices en tablas grandes puede llevar cierto tiempo, no se han añadido automáticamente. Se pueden añadir manualmente dichos índices perdidos mientras la instancia sigue funcionando si se ejecuta \"occ db:add-missing-indices\". Una vez se han añadido los índices, las consultas a esas tablas suelen ser mucho más rápidas.",
    "Missing primary key on table \"{tableName}\"." : "Falta la clave primaria de la tabla \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas claves primarias. Debido a que añadir claves primarias en tablas grandes podría llevar mucho tiempo, no se añadieron automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\" esas claves primarias faltantes podrían ser añadidas manualmente mientras la instancia sigue funcionando.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Falta la columna opcional \"{columnName}\" en la tabla \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido a que agregar columnas en tablas grandes podría llevar mucho tiempo, no se agregaron automáticamente cuando podían eran opcionales. Al ejecutar \"occ db:add-missing-columns\", esas columnas faltantes se pueden agregar manualmente mientras la instancia sigue ejecutándose. Una vez que se agregen las columnas, algunas características pueden mejorar su capacidad de respuesta o la usabilidad.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "A esta instancia le faltan algunos módulos PHP recomendados. Para mejorar el rendimiento y aumentar la compatibilidad, se recomienda encarecidamente instalarlos.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "El módulo PHP \"imagick\" no está habilitado, y la aplicación Temas sí lo está. Para que la generación de favicon funcione correctamente, es necesario instalar y habilitar este módulo.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Los módulos PHP \"gmp\" y/o \"bcmath\" no están habilitados. Si usas la autenticación sin contraseña WebAuthn, estos módulos son necesarios.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "El módulo php-imagick de esta instancia no tiene soporte para SVG. Para una mejor compatibilidad es recomendable instalarlo.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "A algunas columnas de la base de datos les falta convertirse a \"big int\". Debido a que cambiar los tipos de columna en tablas grandes podría tardar mucho tiempo no fueron cambiadas automáticamente. Ejecutando 'occ db:convert-filecache-bigint'  se pueden aplicar estos cambios pendientes de manera manual. Esta operación debe realizarse cuando el servidor esté sin conexión. Para más detalles, consulte {linkstart}la página de documentación ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente se está usando SQLite como base de datos. Para instalaciones más largas recomendamos cambiar a un motor de bases de datos diferente.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto está particularmente indicado si se usa el cliente de escritorio para la sincronización.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Para migrar a otra base de datos use la herramienta de línea de comandos (CLI): \"occ db:convert-type\", o revise la {linkstart}documentación ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "El límite de memoria de PHP está por debajo del valor recomendado de 512 MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Algunos directorios de apps son propiedad de un usuario diferente del usuario del servidor web. Este puede ser el caso si se han instalado apps manualmente. Comprueba los permisos de los siguientes directorios de apps:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Se utiliza MySQL como base de datos pero no soporta caracteres de 4 bytes. Para poder manejar caracteres de 4 bytes (como los emojis) sin problemas en los nombres de archivos o comentarios, se recomienda activar el soporte de 4 bytes en MySQL. Para más detalles consulta {linkstart}la página de documentación sobre esto ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Esta instancia usa un almacenamiento de objetos basado en S3 como almacenamiento primario. Los archivos subidos se almacena temporalmente en el servidor y por eso se recomienda tener 50 GB de espacio libre en el directorio temporal de PHP. Comprueba los registros para detalles completos sobre la ruta y el espacio disponible. Para mejora esto, por favor, cambia el directorio temporal en el php.ini o aumenta el espacio disponible en esa ruta.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "El directorio temporal de esta instancia apunta a una ubicación que no existe o que es un directorio sin permisos de escritura.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Está accediendo a su instancia a través de una conexión segura, sin embargo tu instancia está generando URLs inseguras. Esto suele significar que está tras un proxy inverso y que las variables de reescritura no están bien configuradas. Por favor, revise la {linkstart}página de documentación acerca de esto ↗{linkend}.",
    "Error occurred while checking server setup" : "Ha ocurrido un error al revisar la configuración del servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles compruebe la {linkstart}documentación ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Tu directorio de datos y tus archivos probablemente sean accesibles desde internet. El archivo .htaccess no funciona. Es muy recomendable que configures tu servidor web de tal manera que el directorio de datos no sea accesible, o que lo muevas fuera de la raíz de documentos del servidor web.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no está configurada como \"{expected}\". Esto es un riesgo potencial de seguridad o privacidad, y se recomienda ajustar esta configuración de forma adecuada.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no está configurada como \"{expected}\". Algunas características podrían no funcionar correctamente, por lo que se recomienda ajustar esta configuración.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no contiene \"{expected}\". \nEste es un riesgo potencial de seguridad o privacidad, por lo que se recomienda ajustar esta configuración.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "La cabecera HTTP \"{header}\" no está configurada a \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Esto puede filtrar información de la página de procedencia. Compruebe las {linkstart}Recomendaciones de W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "La cabecera HTTP \"Strict-Transport-Security\" no está configurada al menos a \"{seconds}\" segundos. Para mejorar la seguridad  se recomienda habilitar HSTS como se describe en los {linkstart}consejos de seguridad ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Se está accediendo al sitio de manera insegura mediante HTTP. Se recomienda encarecidamente que configure su servidor para que requiera HTTPS, como se describe en los {linkstart}consejos de seguridad ↗{linkend}.",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola, mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son sus resultados de búsqueda<script>alert(1)</script></strong>",
    "new" : "Nuevo",
    "_download %n file_::_download %n files_" : ["descargar %n archivos","descargar %n archivos","descargar %n archivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, salir de esta página podrían interrumpir el proceso en algunos entornos.",
    "Update to {version}" : "Actualice a {version}",
    "An error occurred." : "Ocurrió un error.",
    "Please reload the page." : "Recargue/Actualice la página",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización tuvo un problema. Para más información <a href=\"{url}\">consulta nuestro artículo del foro</a> para arreglar este problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización ha fallado. Por favor, informa de este problema a la  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidad de Nextcloud</a>.",
    "Continue to {productName}" : "Continuar a {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundo. ","La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundos. ","La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundos. "],
    "More apps" : "Más aplicaciones",
    "Log in" : "Iniciar sesión",
    "Logging in …" : "Iniciando sesión ...",
    "Server side authentication failed!" : "La autenticación ha fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "An internal error occurred." : "Ha habido un error interno.",
    "Please try again or contact your administrator." : "Por favor reintente nuevamente o contáctese con su administrador.",
    "Password" : "Contraseña",
    "Wrong username or password." : "Usuario o contraseña erróneos.",
    "User disabled" : "Usuario deshabilitado",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos inválidos desde tu IP. Por tanto, tu próximo intento se retrasará 30 segundos.",
    "Username or email" : "Nombre de usuario o email",
    "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar de sesión sin contraseña",
    "Browser not supported" : "Navegador no compatible",
    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
    "Your connection is not secure" : "Tu conexión no es segura",
    "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible bajo una conexión segura.",
    "Reset password" : "Restablecer contraseña",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Se ha enviado a tu dirección de correo un mensaje para reiniciar la contraseña. Si no lo recibes, comprueba si está en el buzón de Correo No Deseado (Spam) o pide ayuda a tu administrador local.",
    "If it is not there ask your local administrator." : "Si no está ahí ponte en contacto con el administrador local",
    "Couldn't send reset email. Please contact your administrator." : "No pudo enviarse el correo para restablecer la contraseña. Por favor, contacte con su administrador.",
    "Password cannot be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor, contacte con su administrador.",
    "Back to login" : "Volver a la identificación",
    "New password" : "Nueva contraseña",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tus archivos están encriptados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, comuníquese con su administrador antes de continuar. ¿De verdad quieres continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Resetting password" : "Restableciendo contraseña",
    "Recommended apps" : "Aplicaciones recomendadas",
    "Loading apps …" : "Cargando apps ...",
    "Could not fetch list of apps from the App Store." : "No es posible obtener la lista de apps de la App Store.",
    "Installing apps …" : "Instalando apps ...",
    "App download or installation failed" : "Falló la descarga o instalación de la App",
    "Cannot install this app because it is not compatible" : "No se puede instalar esta app porque no es compatible.",
    "Cannot install this app" : "No se puede instalar esta app",
    "Skip" : "Saltar",
    "Install recommended apps" : "Instalar las aplicaciones recomendadas",
    "Schedule work & meetings, synced with all your devices." : "Programe trabajo y reuniones, sincronizados con todos sus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenga a sus colegas y amigos en un sólo sitio sin dejar escapar su información privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app se integra bien con Archivos, Contactos y Calendario.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones online y conferencias web – en tu navegador y con apps móviles.",
    "Collaboratively edit office documents." : "Edición colaborativa de documentos Office",
    "Local document editing back-end used by the Collabora Online app." : "Motor (back-end) del editor de documentos usado por la app Collabora Online.",
    "Forgot password?" : "¿Contraseña olvidada?",
    "Log in with a device" : "Iniciar sesión con dispositivo",
    "Back" : "Atrás",
    "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
    "Edit Profile" : "Editar perfil",
    "The headline and about sections will show up here" : "El título y la sección acerca de aparecerán aquí",
    "You have not added any info yet" : "Aún no has añadido nada de información",
    "{user} has not added any info yet" : "{user} no ha añadido aún nada de información",
    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
    "Reset search" : "Resetear búsqueda",
    "Start search" : "Iniciar búsqueda",
    "Search for {name} only" : "Buscar solo por {name}",
    "No results for {query}" : "Sin resultados para {query}",
    "Press enter to start searching" : "Pulse Intro para iniciar la búsqueda",
    "Start typing to search" : "Empieza a escribir para buscar",
    "Loading more results …" : "Cargando más resultados …",
    "Load more results" : "Cargar más resultados",
    "Search" : "Buscar",
    "An error occurred while searching for {type}" : "Ha ocurrido un error al buscar {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Por favor, introduce {minSearchLength} carácter o más para buscar","Por favor, introduce {minSearchLength} caracteres o más para buscar","Por favor, introduce {minSearchLength} caracteres o más para buscar"],
    "Search {types} …" : "Buscar {types}…",
    "Settings" : "Configuraciones",
    "Could not load your contacts" : "No se han podido cargar los contactos",
    "Search contacts …" : "Buscar contactos...",
    "No contacts found" : "No se han encontrado contactos",
    "Show all contacts …" : "Mostrar todos los contactos...",
    "Install the Contacts app" : "Instala la aplicación Contactos",
    "Loading your contacts …" : "Cargando tus contactos...",
    "Looking for {term} …" : "Buscando {term}...",
    "No" : "No",
    "Yes" : "Sí",
    "No files in here" : "Aquí no hay archivos",
    "New folder" : "Nueva carpeta",
    "No more subfolders in here" : "No hay más subcarpetas aquí",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
    "{newName} already exists" : "{newName} ya existe",
    "Choose" : "Seleccionar",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Error al cargar plantilla del seleccionador de archivos: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Error al cargar plantilla del mensaje: {error}",
    "read-only" : "solo lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "New Files" : "Nuevos archivos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Qué archivos desea mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(seleccionados todos)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Show list view" : "Mostrar vista de lista",
    "Show grid view" : "Mostrar vista de cuadrícula",
    "Pending" : "Pendiente",
    "Copy to {folder}" : "Copiar a {folder}",
    "Move to {folder}" : "Mover a {folder}",
    "Saving …" : "Guardando...",
    "Authentication required" : "Se necesita autenticación",
    "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Autenticación fallida, vuelva a intentarlo",
    "seconds ago" : "hace segundos",
    "Connection to server lost" : "Se ha perdido la conexión al servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema al cargar la página, volverá a cargar en %n segundo","Problema al cagar la página, volverá a cargar en %n segundos","Problema al cagar la página, volverá a cargar en %n segundos"],
    "Add to a project" : "Añadir a un proyecto",
    "Show details" : "Mostrar detalles",
    "Hide details" : "Ocultar detalles",
    "Rename project" : "Renombrar proyecto",
    "Failed to rename the project" : "Fallo al renombrar el proyecto",
    "Failed to create a project" : "Fallo al crear el proyecto",
    "Failed to add the item to the project" : "Fallo al añadir el elemento al proyecto",
    "Connect items to a project to make them easier to find" : "Conecta elementos a un proyecto para encontrarlos fácilmente",
    "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
    "New in" : "Nuevo en",
    "View changelog" : "Ver registro de cambios",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña normal",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "No action available" : "No hay acciones disponibles",
    "Error fetching contact actions" : "Error recuperando las acciones de los contactos",
    "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
    "restricted" : "Restringido",
    "invisible" : "invisible",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso denegado",
    "Profile not found" : "Perfil no encontrado",
    "The profile does not exist." : "El perfil no existe.",
    "Back to %s" : "Volver a %s",
    "File not found" : "Archivo no encontrado",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "El documento no se pudo encontrar en el servidor. Es posible que el enlace fuera eliminado o haya caducado.",
    "Too many requests" : "Demasiadas peticiones",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubo demasiadas peticiones desde su red. Vuelva a intentarlo más tarde o póngase en contacto con su administrador si se trata de un error.",
    "Error" : "Error",
    "Previous" : "Anterior",
    "Internal Server Error" : "Error interno del servidor",
    "The server was unable to complete your request." : "El servidor no ha podido completar tu petición.",
    "If this happens again, please send the technical details below to the server administrator." : "Si sucede de nuevo, por favor, envía los detalles técnicos a continuación al administrador del servidor.",
    "More details can be found in the server log." : "Pueden verse más detalles en el registro del servidor.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de la solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Trazas",
    "Security warning" : "Advertencia de seguridad",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para información sobre cómo configurar adecuadamente el servidor, revisa por favor la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Show password" : "Mostrar contraseña",
    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
    "Storage & database" : "Almacenamiento y base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Solo %s está disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
    "For more details check out the documentation." : "Para más detalles revisar la documentación.",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique el numero del puerto junto al nombre del host (p.e., localhost:5432).",
    "Performance warning" : "Advertencia de rendimiento",
    "You chose SQLite as database." : "Has elegido SQLite como base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debería usarse para instancias mínimas y de desarrollo. Para producción recomendamos un motor de bases de datos diferente.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso del SQLite está muy desaconsejado.",
    "Install" : "Instalar",
    "Installing …" : "Instalando …",
    "Need help?" : "¿Necesita ayuda?",
    "See the documentation" : "Vea la documentación",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que estás intentando reinstalar Nextcloud. Sin embargo el archivo CAN_INSTALL no se encuentra en la carpeta config. Por favor, crea el archivo CAN_INSTALL en la carpeta config para continuar",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No se puede eliminar el archivo CAN_INSTALL de la carpeta config. Por favor, eliminalo manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere JavaScript para operar correctamente. Por favor, {linkstart}habilite JavaScript{linkend} y recargue la página.",
    "Skip to main content" : "Saltar al contenido principal",
    "Skip to navigation of app" : "Saltar a la navegación de la app",
    "Get your own free account" : "Consigue tu propia cuenta gratuita",
    "%s's homepage" : "%s página de inicio",
    "Contacts" : "Contactos",
    "Contacts menu" : "Menú de contactos",
    "Confirm your password" : "Confirme su contraseña",
    "Connect to your account" : "Conectar a cuenta",
    "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no estás intentando añadir un nuevo dispositivo o una nueva app, alguien está intentando engañarte para que proporciones acceso a tus datos. En este caso, no prosigas y en su lugar avisa a tu administrador de sistemas.",
    "App token" : "Token de la aplicación",
    "Grant access" : "Conceder acceso",
    "Alternative log in using app token" : "Inicio de sesión alternativo usando el token de la aplicación",
    "Account access" : "Acceso a la cuenta",
    "Currently logged in as %1$s (%2$s)." : "Actualmente está conectado como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Estás a punto de conceder a %1$s acceso a tu cuenta %2$s.",
    "Account connected" : "Cuenta conectada",
    "Your client should now be connected!" : "Tu cliente debería estar ahora conectado.",
    "You can close this window." : "Puedes cerrar esta ventana.",
    "This share is password-protected" : "Este recurso compartido está protegido por contraseña",
    "The password is wrong or expired. Please try again or request a new one." : "La contraseña está mal o ha caducado. Por favor, inténtalo de nuevo o solicita una nueva.",
    "Please type in your email address to request a temporary password" : "Escriba su dirección de correo electrónico para solicitar una contraseña temporal",
    "Email address" : "Dirección de correo",
    "Password sent!" : "¡Contraseña enviada!",
    "You are not authorized to request a password for this share" : "No está autorizado a solicitar una contraseña para esta acción",
    "Go to %s" : "Ir a %s",
    "Two-factor authentication" : "Verificación en dos pasos",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguridad mejorada está habilitada para su cuenta. Elija una segunda forma de autenticación:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No se pudo cargar al menos uno de sus métodos de autenticación de segundo paso. Por favor, póngase en contacto con un administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "La autenticación en dos pasos es obligatoria pero no se ha configurado en su cuenta. Póngase en contacto con su administrador para obtener ayuda.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "La autenticación de dos factores es obligatoria pero no se ha configurado en tu cuenta. Por favor, continúa para configurar la autenticación de dos factores.",
    "Set up two-factor authentication" : "Configurar autenticación de dos factores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "La autenticación en dos pasos es obligatoria pero no se ha configurado en su cuenta. Use uno de sus códigos de respaldo para iniciar sesión o comuníquese con su administrador para obtener ayuda.",
    "Use backup code" : "Usar código de respaldo",
    "Cancel login" : "Cancelar inicio de sesión",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Es obligatorio usar la seguridad mejorada en tu cuenta. Escoge qué proveedor configurar:",
    "Error while validating your second factor" : "Error al validar su segundo factor",
    "Access through untrusted domain" : "Acceso a través de un dominio del que no se confía",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor, ponte en contacto con tu administrador. Si eres un administrador, edita la configuración \"trusted_domains\" en config/config.php como en el ejemplo que aparece en config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Más información sobre cómo configurar esto se puede encontrar en la %1$sdocumentación%2$s.",
    "App update required" : "Es necesaria una actualización en la aplicación",
    "%1$s will be updated to version %2$s" : "%1$s se actualizará a la versión %2$s",
    "The following apps will be updated:" : "Se actualizarán las siguientes apps:",
    "These incompatible apps will be disabled:" : "Estas aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido desactivado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Antes de proceder, asegúrese de que se haya hecho un respaldo de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tiempos de espera en grandes instalaciones, en su lugar puede ejecutar el siguiente comando desde el directorio de instalación:",
    "Detailed logs" : "Registros detallados",
    "Update needed" : "Se necesita actualización",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Utilice el actualizador de línia de comandos porque tiene una instancia con más de 50 usuarios.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obtener ayuda, consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si continúo haciendo la actualización a través de la interfaz web, tengo el riesgo de que la solicitud no se ejecute en el tiempo de espera y provoque pérdida de información pero tengo una copia de seguridad de los datos y sé como restaurarla.",
    "Upgrade via web on my own risk" : "Actualizar a través de la web con mi consentimiento.",
    "Maintenance mode" : "Modo mantenimiento",
    "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, y puede tardar un rato.",
    "This page will refresh itself when the instance is available again." : "Esta página se actualizará sola cuando la instancia esté disponible de nuevo.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Zona de comprobación %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no tiene conexión a internet: no se ha podido alcanzar múltiples puntos finales. Esto significa que algunas de las características, como montar almacenamientos externos, notificaciones sobre actualizaciones o instalación de apps de terceras partes no funcionarán. Acceder remotamente a los archivos y enviar correos de notificación tampoco funcionará. Debes establecer una conexión del servidor a internet para disfrutar todas las características.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 es la última versión que soporta PHP 7.2. Nextcloud 21 requiere al menos PHP 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "El módulo OPcache de PHP no está cargado. {linkstart}Para mejorar el rendimiento se recomienda ↗{linkend} cargarlo en su instalación de PHP.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "El módulo OPcache de PHP no está bien configurado. {linkstart}Para mejorar el rendimiento se recomienda ↗{linkend} usar las siguientes configuraciones en el </code>php.ini</code>:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "A algunas columnas de la base de datos les falta convertirse a \"big int\". Debido a que cambiar los tipos de columna en tablas grandes podría tardar mucho tiempo no fueron cambiadas automáticamente. Ejecutando 'occ db:convert-filecache-bigint'  se pueden aplicar estos cambios pendientes de manera manual. Esta operación debe realizarse cuando el servidor esté sin conexión. Para más detalles, consulte {linkstart}la página de documentación ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Para migrar a otra base de datos use la herramienta de línea de comandos (CLI): 'occ db:convert-type', o revise la {linkstart}documentación ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Tu directorio de datos y tus archivos son probablemente accesibles desde internet. El archivo .htaccess no funciona. Se recomienda encarecidamente que configures tu servidor web de tal manera que el directorio de datos no sea accesible, o que lo muevas fuera de la raíz de documentos del servidor web.",
    "More" : "Más",
    "More apps menu" : "Menú de otras apps",
    "Settings menu" : "Menú de configuraciones",
    "The password is wrong. Try again." : "La contraseña es incorrecta. Vuelve a intentarlo.",
    "Setup two-factor authentication" : "Configurar autenticación de dos factores",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Esta es la versión para la comunidad, sin soportede Nextcloud. Dado el tamaño de esta instancia, no se puede garantizar el rendimiento, la fiabilidad y la escalabilidad. Las notificaciones Push han sido desactivadas para evitar sobrecargas en nuestro servicio gratuito. Más información sobre las ventajas de Nextcloud Enterprise en nextcloud.com/enterprise.",
    "You haven't added any info yet" : "Aún no has añadido ninguna información",
    "{user} hasn't added any info yet" : "{user} no ha añadido aún ninguna información"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
